@@ -1,3 +1,8 @@
+/**
+ * Copyright (c) HashiCorp, Inc.
+ * SPDX-License-Identifier: MPL-2.0
+ */
+
 import { FileBase } from "projen";
 import { JsiiProject } from "projen/lib/cdk";
 import { ConstructLibraryCdktf } from "projen/lib/cdktf";
@@ -149,4 +154,15 @@ new JsiiDocgen(project, {
 
 project.jest?.addIgnorePattern("dist");
 project.addKeywords("cdktf", "terraform");
+
+// Run copywrite tool to add copyright headers to all files
+project.buildWorkflow?.addPostBuildSteps(
+  {
+    name: "Setup Copywrite tool",
+    uses: "hashicorp/setup-copywrite@3ace06ad72e6ec679ea8572457b17dbc3960b8ce", // v1.0.0
+    with: { token: "${{ secrets.GITHUB_TOKEN }}" },
+  },
+  { name: "Add headers using Copywrite tool", run: "copywrite headers" }
+);
+
 project.synth();
